% preparedata.m
%
% create test data for AStarOMP software package and store them in 
% supported binary or txt format. 
%                                                                                                    
% Nazm Burak Karahanolu                                                 
% 2011, Sabanc University, stanbul                                      
% email: karahanoglu@sabanciuniv.edu, burak.karahanoglu@gmail.com         

%% parameters
NoVect = 10;   % number of test vectors
N = 256;        % signal dimension
K = 35;         % sparsity
M = 100;        % no measurements

%% create sparse signals
X = zeros(N,NoVect);
for j = 1:NoVect   
    ind = randperm(N);
    X(ind(1:K),j) = randn(K,1);
end

%% create observation matrix and observations
% use a seperate observation matrix for each test vector
Y = zeros(M,NoVect);                % observations
Phi = zeros(M*N,NoVect);            % measurement matrices
for j = 1:NoVect   
    V = randn(M,N);
    Phi(:,j) = V(:);    
    Y(:,j) = V*X(:,j);   
end;

% % alternatively, use the same observation matrix for each test vector
% Phi = randn(M,N);
% Y = Phi*X;

%% save test data in binary format
fid = fopen('X.bin','wb');  fwrite(fid,X,'float32'); fclose(fid);
fid = fopen('Y.bin','wb');  fwrite(fid,Y,'float32'); fclose(fid);
fid = fopen('Phi.bin','wb');  fwrite(fid,Phi,'float32'); fclose(fid);

%% save test data in txt format 
% note: binary format is usually faster...
X_ = X'; Y_ = Y'; Phi_ = Phi';     % invert for txt output
save('X.txt','X_','-ascii');
save('Y.txt','Y_','-ascii');
save('Phi.txt','Phi_','-ascii');